@@ -5,19 +5,9 @@ import sys
 import shutil
 
 import mock
-from zc.recipe.egg.egg import Scripts as ZCRecipeEggScripts
 
 from djangorecipe.recipe import Recipe
 
-# Add the testing dir to the Python path so we can use a fake Django
-# install. This needs to be done so that we can use this as a base for
-# mock's with some of the tests.
-sys.path.insert(0, os.path.join(os.path.dirname(__file__), 'testing'))
-
-# Now that we have a fake Django on the path we can import the
-# scripts. These are depenent on a Django install, hence the fake one.
-from djangorecipe import test
-
 
 class TestRecipe(unittest.TestCase):
 
@@ -103,7 +93,7 @@ class TestRecipe(unittest.TestCase):
         # unlikely that it will generate the same key a few times in a
         # row we will test it with letting it generate a few keys.
         self.assert_(len(set(
-                    [self.recipe.generate_secret() for i in xrange(10)])) > 1)
+                    [self.recipe.generate_secret() for i in range(10)])) > 1)
 
     def test_make_protocol_scripts(self):
         # To ease deployment a WSGI script can be generated. The
@@ -152,7 +142,7 @@ class TestRecipe(unittest.TestCase):
         contents = open(fcgi_script).read()
         self.assert_("logfile='/foo'" in contents)
 
-    @mock.patch('zc.buildout.easy_install', 'scripts')
+    @mock.patch('zc.buildout.easy_install.scripts')
     def test_make_protocol_scripts_return_value(self, scripts):
         # The return value of make scripts lists the generated scripts.
         self.recipe.options['wsgi'] = 'true'
@@ -228,18 +218,14 @@ class TestRecipe(unittest.TestCase):
         self.assert_("djangorecipe.manage.main('spameggs.development')"
                      in open(manage).read())
 
-    @mock.patch('shutil', 'rmtree')
-    @mock.patch('os.path', 'exists')
-    @mock.patch('urllib', 'urlretrieve')
-    @mock.patch('shutil', 'copytree')
-    @mock.patch(ZCRecipeEggScripts, 'working_set')
-    @mock.patch('zc.buildout.easy_install', 'scripts')
-    @mock.patch(Recipe, 'create_manage_script')
-    @mock.patch(Recipe, 'create_test_runner')
-    @mock.patch('zc.recipe.egg', 'Develop')
-    def test_extra_paths(self, rmtree, path_exists, urlretrieve,
-                                   copytree, working_set, scripts,
-                                   manage, testrunner, develop):
+    @mock.patch('os.path.exists')
+    @mock.patch('zc.recipe.egg.egg.Scripts.working_set')
+    @mock.patch('zc.buildout.easy_install.scripts')
+    @mock.patch('djangorecipe.recipe.Recipe.create_manage_script')
+    @mock.patch('djangorecipe.recipe.Recipe.create_test_runner')
+    def test_extra_paths(self, testrunner, manage, scripts,
+                         working_set, path_exists):
+
         # The recipe allows extra-paths to be specified. It uses these to
         # extend the Python path within it's generated scripts.
         self.recipe.options['version'] = '1.0'
@@ -249,24 +235,19 @@ class TestRecipe(unittest.TestCase):
         manage.return_value = []
         scripts.return_value = []
         testrunner.return_value = []
-        develop.return_value = mock.Mock()
         self.recipe.install()
         self.assertEqual(manage.call_args[0][0][-2:],
                          ['somepackage', 'anotherpackage'])
 
-    @mock.patch('shutil', 'rmtree')
-    @mock.patch('os.path', 'exists')
-    @mock.patch('urllib', 'urlretrieve')
-    @mock.patch('shutil', 'copytree')
-    @mock.patch(ZCRecipeEggScripts, 'working_set')
-    @mock.patch('zc.buildout.easy_install', 'scripts')
-    @mock.patch(Recipe, 'create_manage_script')
-    @mock.patch(Recipe, 'create_test_runner')
-    @mock.patch('site', 'addsitedir')
-    @mock.patch('zc.recipe.egg', 'Develop')
-    def test_pth_files(self, rmtree, path_exists, urlretrieve,
-                       copytree, working_set, scripts,
-                       manage, testrunner, addsitedir, develop):
+    @mock.patch('os.path.exists')
+    @mock.patch('zc.recipe.egg.egg.Scripts.working_set')
+    @mock.patch('zc.buildout.easy_install.scripts')
+    @mock.patch('djangorecipe.recipe.Recipe.create_manage_script')
+    @mock.patch('djangorecipe.recipe.Recipe.create_test_runner')
+    @mock.patch('site.addsitedir')
+    def test_pth_files(self, addsitedir, testrunner, manage,
+                       scripts, working_set, path_exists,):
+
         # When a pth-files option is set the recipe will use that to add more
         # paths to extra-paths.
         self.recipe.options['version'] = '1.0'
@@ -275,7 +256,6 @@ class TestRecipe(unittest.TestCase):
         scripts.return_value = []
         manage.return_value = []
         testrunner.return_value = []
-        develop.return_value = mock.Mock()
 
         # The mock values needed to demonstrate the pth-files option.
         addsitedir.return_value = ['extra', 'dirs']
@@ -311,42 +291,6 @@ class TestRecipe(unittest.TestCase):
         self.assert_("djangorecipe.manage.main('project.spameggs')"
                      in open(manage).read())
 
-    @mock.patch('shutil', 'rmtree')
-    @mock.patch('os.path', 'exists')
-    @mock.patch('urllib', 'urlretrieve')
-    @mock.patch('shutil', 'copytree')
-    @mock.patch(ZCRecipeEggScripts, 'working_set')
-    @mock.patch('zc.buildout.easy_install', 'scripts')
-    @mock.patch('subprocess', 'call')
-    def test_update_with_cache(self, rmtree, path_exists, urlretrieve,
-                               copytree, working_set, scripts,
-                               call_process):
-        path_exists.return_value = True
-        working_set.return_value = (None, [])
-        # When the recipe is asked to do an update whilst in install
-        # from cache mode it just ignores it
-        self.recipe.install_from_cache = True
-        self.recipe.update()
-        self.failIf(call_process.called)
-
-    @mock.patch('shutil', 'rmtree')
-    @mock.patch('os.path', 'exists')
-    @mock.patch('urllib', 'urlretrieve')
-    @mock.patch('shutil', 'copytree')
-    @mock.patch(ZCRecipeEggScripts, 'working_set')
-    @mock.patch('zc.buildout.easy_install', 'scripts')
-    @mock.patch('subprocess', 'call')
-    def test_update_with_newest_false(self, rmtree, path_exists, urlretrieve,
-                                      copytree, working_set, scripts,
-                                      call_process):
-        path_exists.return_value = True
-        working_set.return_value = (None, [])
-        # When the recipe is asked to do an update whilst in install
-        # from cache mode it just ignores it
-        self.recipe.buildout['buildout']['newest'] = 'false'
-        self.recipe.update()
-        self.assertFalse(call_process.called)
-
     def test_python_option(self):
         # The python option makes it possible to specify a specific Python
         # executable which is to be used for the generated scripts.
@@ -403,15 +347,13 @@ class TestRecipe(unittest.TestCase):
                          'secret': secret,
                          'urlconf': self.recipe.options['urlconf'],
                          }
-        from boilerplate import versions
+        from djangorecipe.boilerplate import versions
         self.assertEquals(versions['Newest']['settings'] % settings_dict,
                           settings)
 
     def test_boilerplate_1_2(self):
         """Test the boilerplate for django 1.2."""
 
-        secret = '$55upfci7a#gi@&e9o1-hb*k+f$3+(&b$j=cn67h#22*0%-bj0'
-        self.recipe.generate_secret = lambda: secret
         recipe = Recipe({
                 'buildout': {'eggs-directory': self.eggs_dir,
                              'develop-eggs-directory': self.develop_eggs_dir,
@@ -429,6 +371,7 @@ class TestRecipe(unittest.TestCase):
                         'django',
                         {'recipe': 'djangorecipe',
                          'python': 'py5k', 'wsgi': 'true'})
+
         secret = '$55upfci7a#gi@&e9o1-hb*k+f$3+(&b$j=cn67h#22*0%-bj0'
         recipe.generate_secret = lambda: secret
 
@@ -439,7 +382,7 @@ class TestRecipe(unittest.TestCase):
                          'secret': secret,
                          'urlconf': self.recipe.options['urlconf'],
                          }
-        from boilerplate import versions
+        from djangorecipe.boilerplate import versions
         self.assertEquals(versions['1.2']['settings'] % settings_dict,
                           settings)
 
@@ -468,16 +411,17 @@ class ScriptTestCase(unittest.TestCase):
 
 class TestTestScript(ScriptTestCase):
 
-    @mock.patch('django.core.management', 'execute_manager')
+    @mock.patch('django.core.management.execute_manager')
     def test_script(self, execute_manager):
         # The test script should execute the standard Django test
         # command with any apps given as its arguments.
+        from djangorecipe import test
         test.main('cheeseshop.development',  'spamm', 'eggs')
         # We only care about the arguments given to execute_manager
         self.assertEqual(execute_manager.call_args[1],
                          {'argv': ['test', 'test', 'spamm', 'eggs']})
 
-    @mock.patch('django.core.management', 'execute_manager')
+    @mock.patch('django.core.management.execute_manager')
     def test_deeply_nested_settings(self, execute_manager):
         # Settings files can be more than two levels deep. We need to
         # make sure the test script can properly import those. To
@@ -489,21 +433,28 @@ class TestTestScript(ScriptTestCase):
         sys.modules['cheeseshop'].nce = nce
         sys.modules['cheeseshop.nce'] = nce
         sys.modules['cheeseshop.nce.development'] = settings
-
+        from djangorecipe import test
         test.main('cheeseshop.nce.development',  'tilsit', 'stilton')
         self.assertEqual(execute_manager.call_args[0], (settings,))
 
-    @mock.patch('sys', 'exit')
-    def test_settings_error(self, sys_exit):
+    @mock.patch('sys.stderr.write')
+    @mock.patch('sys.exit')
+    def test_settings_error(self, sys_exit, stderr_write):
         # When the settings file cannot be imported the test runner
         # wil exit with a message and a specific exit code.
-        test.main('cheeseshop.tilsit', 'stilton')
+        from djangorecipe import test
+        self.assertRaises(UnboundLocalError, test.main, 'cheeseshop.tilsit',
+                          'stilton')
+        self.assertEqual(stderr_write.call_args,
+                         (("Error loading the settings module "
+                           "'cheeseshop.tilsit': "
+                           "No module named tilsit",), {}))
         self.assertEqual(sys_exit.call_args, ((1,), {}))
 
 
 class TestManageScript(ScriptTestCase):
 
-    @mock.patch('django.core.management', 'execute_manager')
+    @mock.patch('django.core.management.execute_manager')
     def test_script(self, execute_manager):
         # The manage script is a replacement for the default manage.py
         # script. It has all the same bells and whistles since all it
@@ -513,12 +464,71 @@ class TestManageScript(ScriptTestCase):
         self.assertEqual(execute_manager.call_args,
                          ((self.settings,), {}))
 
-    @mock.patch('sys', 'exit')
-    def test_settings_error(self, sys_exit):
+    @mock.patch('sys.stderr.write')
+    @mock.patch('sys.exit')
+    def test_settings_error(self, sys_exit, stderr_write):
         # When the settings file cannot be imported the management
         # script it wil exit with a message and a specific exit code.
         from djangorecipe import manage
-        manage.main('cheeseshop.tilsit')
+        self.assertRaises(UnboundLocalError, manage.main, 'cheeseshop.tilsit')
+        self.assertEqual(stderr_write.call_args,
+                         (("Error loading the settings module "
+                           "'cheeseshop.tilsit': "
+                           "No module named tilsit",), {}))
+        self.assertEqual(sys_exit.call_args, ((1,), {}))
+
+
+class TestFCGIScript(ScriptTestCase):
+
+    @mock.patch('django.conf.settings')
+    @mock.patch('django.core.management.setup_environ')
+    @mock.patch('django.core.servers.fastcgi.runfastcgi')
+    def test_script(self, runfastcgi, setup_environ, settings):
+        # The fcgi is a warpper for the django fcgi script.
+        from djangorecipe import fcgi
+        settings.FCGI_OPTIONS = {}
+        fcgi.main('cheeseshop.development', logfile=None)
+        self.assertEqual(setup_environ.call_args,
+                         ((self.settings,), {}))
+        self.assertEqual(runfastcgi.call_args, {})
+
+    @mock.patch('sys.stderr.write')
+    @mock.patch('sys.exit')
+    def test_settings_error(self, sys_exit, stderr_write):
+        # When the settings file cannot be imported the fcgi
+        # script it wil exit with a message and a specific exit code.
+        from djangorecipe import fcgi
+        self.assertRaises(UnboundLocalError, fcgi.main, 'cheeseshop.tilsit')
+        self.assertEqual(stderr_write.call_args,
+                         (("Error loading the settings module "
+                           "'cheeseshop.tilsit': "
+                           "No module named tilsit",), {}))
+        self.assertEqual(sys_exit.call_args, ((1,), {}))
+
+
+class TestWSGIScript(ScriptTestCase):
+
+    @mock.patch('django.core.management.setup_environ')
+    @mock.patch('django.core.handlers.wsgi.WSGIHandler')
+    def test_script(self, WSGIHandler, setup_environ):
+        # The fcgi is a warpper for the django fcgi script.
+        from djangorecipe import wsgi
+        wsgi.main('cheeseshop.development', logfile=None)
+        self.assertEqual(WSGIHandler.call_args, {})
+
+    @mock.patch('sys.stderr.write')
+    @mock.patch('sys.exit')
+    def test_settings_error(self, sys_exit, stderr_write):
+        # When the settings file cannot be imported the wsgi
+        # script it wil exit with a message and an specific exit code.
+        from djangorecipe import wsgi
+        #Catch the error that has to occur because sys.exit is patched
+        #and doesn't exit automatically.
+        self.assertRaises(UnboundLocalError, wsgi.main, 'cheeseshop.tilsit')
+        self.assertEqual(stderr_write.call_args,
+                         (("Error loading the settings module "
+                           "'cheeseshop.tilsit': "
+                           "No module named tilsit",), {}))
         self.assertEqual(sys_exit.call_args, ((1,), {}))
 
 
@@ -527,4 +537,9 @@ def test_suite():
             unittest.makeSuite(TestRecipe),
             unittest.makeSuite(TestTestScript),
             unittest.makeSuite(TestManageScript),
+            unittest.makeSuite(TestFCGIScript),
+            unittest.makeSuite(TestWSGIScript),
             ))
+
+if __name__ == '__main__':
+        unittest.main()
